# Autogenerated by Astropy's setup.py on 2019-06-09 01:10:17 UTC
from __future__ import unicode_literals
import datetime

version = "2.0.13"
githash = "89b6be94196e51a45d56a23b03e1bff9f74b89b9"


major = 2
minor = 0
bugfix = 13

release = True
timestamp = datetime.datetime(2019, 6, 9, 1, 10, 17)
debug = False

astropy_helpers_version = "2.0.10.dev860"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
